==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/SvgImport/ts/SvgImport_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SvgImport</name>
    <message>
        <location filename="../SvgImport.js" line="+30"/>
        <source>File</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Import SVG</source>
        <translation>Uvozi SVG</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SVG Files</source>
        <translation>SVG datoteke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files</source>
        <translation>Vse datoteke</translation>
    </message>
    <message>
        <location line="-34"/>
        <location filename="../SvgImportDialog.ui" line="+14"/>
        <source>SVG Import</source>
        <translation>Uvozi SVG</translation>
    </message>
    <message>
        <location filename="../SvgImportDialog.ui" line="+8"/>
        <source>Resolution:</source>
        <translation>Resolucija:</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Pixels / Inch</source>
        <translation>Piksel / Inč</translation>
    </message>
    <message>
        <location filename="../SvgImportInit.js" line="+2"/>
        <source>SVG &amp;Import...</source>
        <translation>&amp;Uvozi SVG...</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Splines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically convert splines to lines / arcs if appropriate</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/SvgImport/ts/SvgImport_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>SvgImport</name>
    <message>
        <location filename="../SvgImport.js" line="+30"/>
        <source>File</source>
        <translation>Datoteka</translation>
    </message>
    <message>
        <location line="+33"/>
        <source>Import SVG</source>
        <translation>Uvozi SVG</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>SVG Files</source>
        <translation>SVG datoteke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>All Files</source>
        <translation>Vse datoteke</translation>
    </message>
    <message>
        <location line="-34"/>
        <location filename="../SvgImportDialog.ui" line="+14"/>
        <source>SVG Import</source>
        <translation>Uvozi SVG</translation>
    </message>
    <message>
        <location filename="../SvgImportDialog.ui" line="+8"/>
        <source>Resolution:</source>
        <translation>Resolucija:</translation>
    </message>
    <message>
        <location line="+57"/>
        <source>Pixels / Inch</source>
        <translation>Piksel / Inč</translation>
    </message>
    <message>
        <location filename="../SvgImportInit.js" line="+2"/>
        <source>SVG &amp;Import...</source>
        <translation>&amp;Uvozi SVG...</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Splines</source>
        <translation>Krivulje</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Automatically convert splines to lines / arcs if appropriate</source>
        <translation>Samodejno pretvori krivulje v črte / loke če ustreza</translation>
    </message>
</context>
</TS>
